
var background = ({

    apps: null,
    PostedCreds: [],
    portalUrl: null,
    updateTime: null,

    initialize: function () {

        var appData = localStorage.getItem('appData');

        if (appData !== null)
            this.apps = JSON.parse(appData);

        chrome.runtime.onMessage.addListener(background.onMessageListener);

        chrome.webRequest.onAuthRequired.addListener(
            function (details, callbackFn) {
                try
                {
                    if (background.portalUrl === null)
                        return callbackFn({ cancel: false });

                    background.getApps(null);

                    var app = SSO.Util.getAppFromHostName(background.apps, details.realm, details.url);
                    if (app == null)
                        return callbackFn({ cancel: false });

                    if (app.authTried === true)
                        return callbackFn({ cancel: false });

                    app.authTried = true;

                    if (app.credentialSets === null)
                        return callbackFn({ cancel: false });

                    var credentialSet = app.credentialSets[0];

                    var usrname = SSO.Util.getCredentialByFunction(credentialSet, "username");
                    var pwd = SSO.Util.getCredentialByFunction(credentialSet, "password");

                    if (usrname == null || pwd == null)
                        return callbackFn({ cancel: false });

                    return callbackFn({ authCredentials: { username: usrname.value, password: pwd.value } });
                }
                catch(e)
                {
                    return callbackFn({ cancel: false });
                }
            },
            { urls: ["<all_urls>"] }
        );

        chrome.webRequest.onBeforeRequest.addListener(
            function (details, callbackFn) {

                if (background.portalUrl === null)
                    return;
                chrome.cookies.get({ "url": background.portalUrl, "name": "_helloidentiy" }, function (cookie) {
                    if (cookie !== null && details.method === 'POST') {
                        var regex = new RegExp(background.portalUrl + 'configure/save.*',"i");

                        if (regex.exec(details.url))
                        {
                            SSO.Util.resetCredentials(background.apps);
                            return;
                        }
                        regex = new RegExp(background.portalUrl + 'configure/credentialdelete.*', "i");
                        if (regex.exec(details.url)) {
                            SSO.Util.resetCredentials(background.apps);
                            return;
                        }
                    }
                });
            },
            { urls: ["<all_urls>"] }
        );
    },

    onMessageListener: function (message, sender, sendResponse) {
        switch (message.id) {
            case "Discovered":

                var newPortalURL = message.data.portalUrl.toLowerCase();

                if (!SSO.Util.isNullOrEmpty(background.portalUrl) && background.portalUrl.toLowerCase() !== newPortalURL)
                {
                    background.apps = null;
                    background.PostedCreds.length = 0;
                    background.updateTime = null;
                }
                background.portalUrl = newPortalURL;

                chrome.storage.sync.set({ portalLocation: background.portalUrl });

                background.getApps(null);

                return true;
            case "Initialize":

                if (background.portalUrl === null)
                    return true;

                background.getApps(function () { background.onInitialize(sender.tab.id, message.data.hostname, message.data.href); });

                return true;

            case "NewCredsPosted":
                var app = SSO.Util.getAppFromGUID(background.apps,message.data.applicationGUID);
                if (app == null)
                    return true;

                if (SSO.Util.isCredentialSetNewOrChanged(app, message.data)) {
                    SSO.Util.deleteNewCred(background.PostedCreds, app);
                    background.PostedCreds.push(message.data);
                    sendToTab(sender.tab.id,"SaveCredentialsQuestion", app);
                }

                return true;

            case "CancelSaveCredential":

                var app = SSO.Util.getAppFromGUID(background.apps, message.data);
                if (app == null)
                    return true;

                SSO.Util.deleteNewCred(background.PostedCreds, app);

                sendToTab(sender.tab.id, "RetrievedApplicationData", app);

                return true;

            case "SaveCredential":
                var app = SSO.Util.getAppFromGUID(background.apps, message.data);
                if (app == null)
                    return true;

                var newCreds = SSO.Util.getNewCreds(background.PostedCreds, app);
                SSO.Util.deleteNewCred(background.PostedCreds, app);
                SSO.Util.updateCredentials(app, newCreds);

                background.updateCred(app);

                sendToTab(sender.tab.id, "RetrievedApplicationData", app);

                return true;
            case "ShowCredBanner":

                var app = SSO.Util.getAppFromGUID(background.apps, message.data.applicationGUID);

                if (app == null)
                    return true;

                background.getCredentials(app);

                if (app.credentialSets !== undefined && app.credentialSets.length > 0) {
                    message.data.app = app;

                    sendToTab(sender.tab.id, "ShowCredBanner", message.data);
                }
                return true;
            case "FillFormWithCredentials":
                var app = SSO.Util.getAppFromGUID(background.apps,  message.data.applicationGUID);

                if (app == null)
                    return true;

                if (app.credentialSets !== undefined && app.credentialSets.length > 0) {
                    message.data.credentialSets = app.credentialSets;
                    SSO.Util.setPressButtonFlag(app);
                    message.data.pressButton = app.pressButton;
                    sendToTab(sender.tab.id, "FillFormWithCredentials", message.data);
                }
                return true;
            case "ChangePassword":
                var app = SSO.Util.getAppFromGUID(background.apps, message.data.applicationGUID);

                if (app == null)
                    return true;

                if (app.credentialSets !== undefined && app.credentialSets.length > 0) {
                    message.data.credentialSets = app.credentialSets;
                    message.data.newPassword = SSO.Util.generatePassword(16);
                    sendToTab(sender.tab.id, "ChangePassword", message.data);
                }
                return true;
            case "ShowSettingsBanner":
                var app = SSO.Util.getAppFromGUID(background.apps, message.data);

                if (app.credentialSets !== undefined && app.credentialSets.length > 0)
                    sendToTab(sender.tab.id,"ShowSettingsBanner", app);
                return true;
        }
        return true;
    },
    refresh: function ()
    {
        background.apps = null;
        background.PostedCreds.length = 0;
        background.updateTime = null;

        background.getApps(null);
    },
    shouldUpdate: function ()
    {
        if (background.updateTime === null)
            return true;
        if (background.apps === null)
            return true;

        return false;
    },
    getApps: function (callback)
    {
        if (!background.shouldUpdate()) {
            if (callback !== null)
                callback();
            return;
        }

        chrome.cookies.get({ "url": background.portalUrl, "name": "_helloidentiy" }, function (cookie) {
            if (cookie !== null) {
                var response;

                try {
                    response = SSO.Ajax.sendSync(background.portalUrl + 'plugin/GetApplications');
                }
                catch (e) {
                    console.log("exception in GetApplications");
                }

                if (response == null)
                    return;

                var obj = JSON.parse(response);
                if (obj == null)
                    return;

                background.updateTime = Date.UTC();
                background.apps = obj.result;

                localStorage.setItem('appData', JSON.stringify(background.apps));

                if (callback !== null)
                    callback();
            }

            return;
        });
    },
    getCredentials: function (app) {

        var response;
        try {
            response = SSO.Ajax.sendSync(background.portalUrl + 'plugin/GetCredentialData?applicationGuid=' + app.applicationGUID);
        }
        catch (e) {
            console.log("exception in getCredentials");
        }

        if (response == null)
            return;

        var obj = JSON.parse(response);
        if (obj == null)
            return;

        app.credentialSets = obj.result;
    },
    updateCred: function (app) {
        try {
            app.credentialSets[0].ApplicationGUID = app.applicationGUID;
            SSO.Ajax.sendAsync(background.portalUrl + 'plugin/UpdateCredential', JSON.stringify(app.credentialSets[0]));
        }
        catch (e) {
            console.log("exception in updateCred");
        }

    },
    onInitialize: function (tabID,hostname,href)
    {
        var app = SSO.Util.getAppFromHostName(background.apps,hostname,href);
        if (app == null)
            return;

        var NewCreds = SSO.Util.getNewCreds(background.PostedCreds, app);

        if (NewCreds)
            sendToTab("SaveCredentialsQuestion", app);
        else {
            sendToTab(tabID,"RetrievedApplicationData", app);

        }
    },
    logout: function ()
    {
        background.apps = null;

        background.PostedCreds.length = 0;
    }
});

background.initialize();

chrome.storage.sync.get({
    portalLocation: ''
}, function (items) {
    background.portalUrl = items.portalLocation;
});

chrome.cookies.onChanged.addListener(function (changeInfo) {
    if (changeInfo.cookie.name === "_helloidentiy") {

        if (changeInfo.cause === 'expired_overwrite') {
            background.logout();
        }
    }
    
});

function sendToTab(tabID,id, data) {
    var model = {};

    model.id = id;
    model.data = data;

    chrome.tabs.sendMessage(tabID, model);
};