﻿
var SSO = {

};

SSO.Models    = {};
SSO.Services  = {};

SSO.Util = {

    // extend an object with properties of one or more other objects
    extend: function (dest) {
        var i;
        var j;
        var len;
        var src;
        for (j = 1, len = arguments.length; j < len; j++) {
            src = arguments[j];
            for (i in src) {
                if(src.hasOwnProperty(i)) {
                    dest[i] = src[i];
                }
            }
        }
        return dest;
    },

    // create an object from a given prototype
    create: Object.create || (function () {
        function F() {}
        return function (proto) {
            F.prototype = proto;
            return new F();
        };
    })(),
    delegateEvent : function(sender,method,eventArgs)
    {
        var args = eventArgs;
        return function (event) { sender[method](event, args); }
    },
    getCredentialByFunction: function (credentialSet, func, newPassword) {

        if (!SSO.Util.isNullOrEmpty(newPassword) && (func.toLowerCase() == 'newpassword' || func.toLowerCase() == 'confirmpassword')) {
            var cred = {};
            cred.value = newPassword;
            return cred;
        }

        if (credentialSet !== null && credentialSet !== undefined)
            if(credentialSet.hasOwnProperty('credentials'))
                for(var i = 0; i < credentialSet.credentials.length; i++)
                {
                    var credential = credentialSet.credentials[i];
                    if (credential.hasOwnProperty('function') && credential["function"].toString().toLowerCase() === func.toString().toLowerCase())
                        return credential;
                }
        return null;
    },
    isNullOrEmpty : function (variable)
    {
        if (variable === undefined)
            return true;
        if (variable == null)
            return true;

        return false;
    },
    updateCredentials: function (app, newSet) {
        var newCreds = newSet.credentials;
        var existingSet = app.credentialSets[0];

        for (var i = 0; i < newCreds.length; i++) {
            var newCred = newCreds[i];
            var found = false;

            for (var j = 0; j < existingSet.credentials.length; j++) {
                var existingCred = existingSet.credentials[j];
                if (existingCred["function"].toLowerCase() === newCred["function"].toLowerCase()) {
                    existingCred.value = newCred.value;
                    found = true;
                    break;
                }
            }
            if(!found)
            {
                existingSet.credentials.push(newCred);
            }

        }
    },
    resetCredentials: function (apps) {

        for (var i = 0; i < apps.length; i++) {
            apps[i].credentialSets = null;
        }
    },
    isCredentialSetNewOrChanged: function (app, newSet) {
        if (newSet.credentials.length === 0)
            return false;
        if (app.credentialSets.length === 0)
            return true;
        if (newSet.credentials.length > app.credentialSets[0].length)
            return true;

        if (SSO.Util.isCredentialSetDifferent(app.credentialSets[0], newSet))
            return true;

        return false;
    },
    isCredentialSetDifferent: function (existingSet, newSet) {
        var newCreds = newSet.credentials;

        for (var i = 0; i < newCreds.length; i++) {
            var newCred = newCreds[i];
            var found = false;

            for (var j = 0; j < existingSet.credentials.length; j++) {
                var existingCred = existingSet.credentials[j];

                if (existingCred["function"].toLowerCase() === newCred["function"].toLowerCase())
                {
                    if (existingCred.userEditAllowed) {
                        if (!SSO.Util.isSameCred(existingCred, newCred))
                            return true;
                    }
                    found = true;
                }
            }
            if (!found)
                return true;
        }

        return false;
    },
    isSameCred: function (existingCred, newCred) {

        if (existingCred["function"].toLowerCase() === ("password")) //Compare password with case!
        {
            if (existingCred.value !== newCred.value)
                return false;
        }
        else {
            if (existingCred.value.toLowerCase() !== newCred.value.toLowerCase())
                return false;
        }
        return true;
    },
    decodeBase64: function (s) {
        var e = {}, i, b = 0, c, x, l = 0, a, r = '', w = String.fromCharCode, L = s.length;
        var A = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
        for (i = 0; i < 64; i++) { e[A.charAt(i)] = i; }
        for (x = 0; x < L; x++) {
            c = e[s.charAt(x)]; b = (b << 6) + c; l += 6;
            while (l >= 8) { ((a = (b >>> (l -= 8)) & 0xff) || (x < (L - 2))) && (r += w(a)); }
        }
        return r;
    },
    getAppFromHostName: function (apps,hostname,url) {
        if (apps == null)
            return null;

        if (hostname != null)
            hostname = hostname.toLowerCase();

        for (var i = 0; i < apps.length; i++) {
            if (apps[i].type.toLowerCase() === 'saml')
                continue;

            if (!this.isStringNullOrEmpty(apps[i].domainsToDetect) && !this.isStringNullOrEmpty(hostname)) {
                if (this.isInStringArray(apps[i].domainsToDetect, hostname))
                    return apps[i];
            }
            if (!this.isStringNullOrEmpty(apps[i].urLsToDetect) && !this.isStringNullOrEmpty(url)) {
                if (this.isInStringArray(apps[i].urLsToDetect, url))
                    return apps[i];
            }

            if (this.isStringNullOrEmpty(apps[i].domainsToDetect) && this.isStringNullOrEmpty(apps[i].urLsToDetect)) {
                if (!this.isStringNullOrEmpty(hostname)) {
                    if (apps[i].url.toLowerCase().search(hostname) !== -1)
                        return apps[i];
                }
            }
        }
        return null;
    },
    isStringNullOrEmpty: function(string)
    {
        if (string == null)
            return true;
        if (string === '')
            return true;
        return false;
    }
    ,
    isInStringArray: function (commaSeparatedString, text) {
        var stringArray = commaSeparatedString.split(',');
        for (var i = 0; i < stringArray.length; i++) {
            var regex = new RegExp(stringArray[i], 'i');
            if (regex.exec(text))
                return true;
        }
        return false;
    },
    getAppFromGUID: function(apps,applicationGuid)
    {
        if (apps == null)
            return null;

        for (var i = 0; i < apps.length; i++) {
            if (applicationGuid.toLowerCase() === apps[i].applicationGUID.toLowerCase())
                return apps[i];
        }
        return null;
    },
    getNewCreds: function (postedCreds,app) {
        for (var i = 0; i < postedCreds.length; i++) {
            if (postedCreds[i].applicationGUID === app.applicationGUID)
                return postedCreds[i];
        }
        return null;
    },
    deleteNewCred: function (postedCreds, app) {
        for (var i = postedCreds.length - 1; i >= 0 ; i--) {
            if (postedCreds[i].applicationGUID === app.applicationGUID) {
                postedCreds.splice(i, 1);
            }
        }
    },
    setPressButtonFlag: function (app) {

        if (!(app.options & 1))
            return ;

        var date = new Date();
        var curTime = date.getTime();

        if (app.buttonPressTime + 10000 > curTime)
        {
            app.pressButton = false;
            return;
        }

        app.buttonPressTime = curTime;
        app.pressButton = true;
    },
    injectScript: function (document) {

        try
        {
            if (document.createEvent === undefined)
                return;
            if (document.getElementById("HelloIDSubmit") !== null)
                return;

            var scriptEl = document.createElement("script");
            scriptEl.innerHTML = 'HTMLFormElement.prototype._nativeSubmit = HTMLFormElement.prototype.submit;HTMLFormElement.prototype.submit = function () {var submitEvent = document.createEvent("HTMLEvents");submitEvent.initEvent("submit", true, false);if (this.dispatchEvent(submitEvent)) {this._nativeSubmit.apply(this, arguments);}};';
            scriptEl.async = false;
            scriptEl.id = "HelloIDSubmit";

            (document.body || document.head || document.documentElement)
            .appendChild(scriptEl);
        }
        catch(e)
        {
        }
    },
    addClickListener: function (object,callback)
    {
        if (object == null)
            return;

        if (object.addEventListener)
            object.addEventListener('click', callback);
        else
            object.attachEvent('onclick', callback);
    },
    addMouseOverListener: function (object, callback) {
        if (object == null)
            return;

        if (object.addEventListener)
            object.addEventListener('mouseover', callback);
        else
            object.attachEvent('onmouseover', callback);
    },
    addMouseOutListener: function (object, callback) {
        if (object == null)
            return;

        if (object.addEventListener)
            object.addEventListener('mouseout', callback);
        else
            object.attachEvent('onmouseout', callback);
    },
    generatePassword: function(length) {
        var chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890`~!@#$%^&*()-_=+[]{}\\|;:'\",<.>/?";
        var pass = "";
        for (var x = 0; x < length; x++) {
            var i = Math.floor(Math.random() * chars.length);
            pass += chars.charAt(i);
        }
        return pass;
    },
    executeHTMLEvent: function (document, element, eventName)
    {
        if (element == null)
            return;

        var event = document.createEvent("HTMLEvents");
        if (event)
        {
            event.initEvent(eventName, true, true);
            element.dispatchEvent(event);
        } else {
            event = document.createEventObject();
            event.eventType = eventName;

            element.fireEvent('on' + eventName, event);
        }
    },
    executeKeyEvent: function (document, element, eventName, keyCode) {
        if (element == null)
            return;

        var event = document.createEvent("HTMLEvents");
        if (event) {
            event.keyCode = keyCode,
                event.initEvent(eventName, true, true),
                element.dispatchEvent(event);
        } else {
            event = document.createEventObject();
            event.keyCode = keyCode;
            event.eventType = eventName;

            element.fireEvent('on' + eventName, event);
        }
    },
    GetLanguage: function (langSet)
    {
        var lang = {};

        switch(langSet)
        {
            case 'EN':
                {
                    lang.EnterCred = "Enter credentials";
                    lang.Default = "Default";
                    lang.Close = "Close";
                    lang.Hide = "Hide";
                    lang.ShowCred = "Show credentials";
                    lang.HideCred = "Hide credentials";
                    lang.SaveQuestion = "Do you want to save and replace your credentials?";
                    lang.Save = "Save";
                    lang.Incorrect = "The data i provided was incorrect";
                    lang.NotNow = "Not now";
                    lang.ChangePwd = "Change Password";
                    break;
                }
            case 'NL':
                {
                    lang.EnterCred = "Vul gegevens in";
                    lang.Default = "Standaard";
                    lang.Close = "Sluiten";
                    lang.Hide = "Verbergen";
                    lang.ShowCred = "Toon gegevens";
                    lang.HideCred = "Verberg gegevens";
                    lang.SaveQuestion = "Wilt u de gewijzigde gegevens opslaan?";
                    lang.Save = "Bewaar";
                    lang.Incorrect = "De ingetypte gegevens zijn onjuist";
                    lang.NotNow = "Niet nu";
                    lang.ChangePwd = "Wachtwoord wijzigen";
                    break;
                }
            case 'FR':
                {
                    lang.EnterCred = "Entrez vos identifiants";
                    lang.Default = "Par défaut";
                    lang.Close = "Fermer";
                    lang.Hide = "Cacher";
                    lang.ShowCred = "Affichez vos identifiants";
                    lang.SaveQuestion = "Voulez-vous sauvegarder ces modifications?";
                    lang.Save = "Sauvegarder";
                    lang.Incorrect = "Les données saisies sont incorrectes";
                    lang.NotNow = "Pas maintenant";
                    lang.ChangePwd = "Changer le mot de passe";
                    break;
                }
            case 'DE':
                {
                    lang.EnterCred = "Anmeldedaten eingeben";
                    lang.Default = "Standard";
                    lang.Close = "Schließen";
                    lang.Hide = "Verstecken";
                    lang.ShowCred = "Anmeldedaten zeigen";
                    lang.HideCred = "Anmeldedaten verstecken";
                    lang.SaveQuestion = "Möchten Sie die Anmeldedaten speichern und ersetzen?";
                    lang.Save = "Speichern";
                    lang.Incorrect = "Die eingegebenden Daten sind fehlerhaft";
                    lang.NotNow = "Nicht jetzt";
                    break;
                }
        }
        

        return lang;
    },
    inIframeChromeIE: function()
    {
        try
        {
            return window.self !== window.top;
        }
        catch (e)
        {
            return true;
        }
    }
};


// shortcuts for most used utility functions
SSO.extend = SSO.Util.extend;
SSO.Class = function () {}; // namespace

//create extend method (behaves like a object)
SSO.Class.extend = function (props) {

	// extended class with the new prototype
	var NewClass = function () {

		// call the constructor
		if (this.initialize) {
			this.initialize.apply(this, arguments);
		}

        //event based functionality (hooks)
		if(this.hook === null || this.hook === undefined)
		{
		    //add hooks
		    this.hook = {
		            hooks: [],

		            register: function (name, callback) {
		                if ('undefined' == typeof (this.hooks[name])) {
                            this.hooks[name] = [];
                        }
		                this.hooks[name].push(callback);
		            },

		            call: function (name, hookargs) {
		                if ('undefined' !== typeof (this.hooks[name]))
		                    for (var i = 0; i < this.hooks[name].length; ++i)
		                        if (true !== this.hooks[name][i](hookargs)) { break; }
		            }
		    }
		}
	};

	var parentProto = NewClass.__super__ = this.prototype;

    //create new prototype constructor
	var proto = SSO.Util.create(parentProto);
	proto.constructor = NewClass;
	NewClass.prototype = proto;

	//inherit parent's statics
	for (var i in this) {
		if (this.hasOwnProperty(i) && i !== 'prototype') {
			NewClass[i] = this[i];
		}
	}

	// mix given properties into the prototype
	SSO.extend(proto, props);

	return NewClass;
};


// method for adding properties to prototype
SSO.Class.include = function (props) {
	SSO.extend(this.prototype, props);
};
SSO.Form = SSO.Class.extend({
    form: null,
    fields: [],
    changePwd: false,

    getCredential: function (type)
    {
        for (var i = 0; i < this.fields.length; i++) {
            if (this.fields[i].type.toLowerCase() === type.toLowerCase())
                return this.fields[i];
        }
        return null;
    },
    hasElement: function (type) {
        for (var i = 0; i < this.fields.length; i++) {
            if (this.fields[i].type.toLowerCase() === type.toLowerCase()) {
                if (this.fields[i].element != null)
                    return true;
            }
        }
        return false;
    },
    addField: function(type,element)
    {
        var field = {};

        field.type = type;
        field.element = element;

        this.fields.push(field);
    },
    shouldIgnoreField: function (type)
    {
        if (type.toLowerCase() === 'submit' || type.toLowerCase() === 'confirmpassword')
            return true;

        if (this.changePwd == true && type.toLowerCase() === 'password')
            return true;

        return false;
    },
    getCredentialList: function()
    {
        var credentialList = new Array();

        for (var i = 0; i < this.fields.length; i++) {

            this.addCredentialToList(this.fields[i], credentialList);
        }

        return credentialList;
    },
    addCredentialToList: function (currentField, credentialList)
    {
        if (currentField.element === null || currentField.element.value === null || this.shouldIgnoreField(currentField.type))
            return;

        var currentType = currentField.type.toLowerCase();
        if (currentType === 'newpassword')
            currentType = 'password';

        var found = false;
        for (var i = 0; i < credentialList.length; i++) {
            if (credentialList[i].function.toLowerCase() === currentType)
            {
                credentialList[i].value = currentField.element.value;
                found = true;
            }
        }
        if(!found)
            credentialList.push({ "value": currentField.element.value, "function": currentType, "userEditAllowed": "true" });
    }
});

SSO.Detection = SSO.Class.extend({

    doc: null,
    forms: [],
    app: null,
    loginDetected: false,
    changePwdDetected: false,

    initialize: function (doc, app) {
        this.doc = doc;
        this.app = app;
    },
    getCredentials: function (event) {
        for (var i = 0; i < this.forms.length; i++)
        {
            if(this.forms[i].form === event.target)
            {
                var currentForm = this.forms[i];
                var result = {};

                result.applicationGUID = this.app.applicationGUID;
                result.CredSetName = "Default";
                result.credentials = currentForm.getCredentialList();

                return result;
            }
        }
        return null;
    },
    createSubmitEvent: function (submitHandler) {
        for (var i = 0; i < this.forms.length; i++) {
            var currentForm = this.forms[i].form;
            if (currentForm !== null && currentForm !== undefined) {
                if (currentForm.addEventListener)
                    currentForm.addEventListener("submit", submitHandler, false);
                else
                    currentForm.attachEvent("onsubmit", submitHandler);
            }
        }
        if (this.app.options & 2)
            SSO.Util.injectScript(document);
    },
    changePassword: function (doc, messageData) {
        for (var i = 0; i < this.forms.length; i++) {

            this.fillCurrentFormWithCredentials(doc, this.forms[i], messageData, messageData.newPassword);
        }
    },
    fillFormWithCredentials: function (doc, messageData) {

        for (var i = 0; i < this.forms.length; i++)
        {
            this.fillCurrentFormWithCredentials(doc, this.forms[i],  messageData);
        }
    },
    fillCurrentFormWithCredentials: function (doc, currentForm,  messageData, newPassword)
    {
        var currentObj = this;

        if (messageData.fromButton)
            this.enterCreds(doc, currentForm, messageData, newPassword);
        else
            setTimeout(function () { currentObj.enterCreds(doc, currentForm, messageData, newPassword); }, 500);

    },
    enterCreds: function (doc, currentForm, messageData, newPassword) {
        var credentialSet = messageData.credentialSets[0];

        for (var i = 0; i < currentForm.fields.length; i++) {
            var currentField = currentForm.fields[i];

            if (currentField.type.toLowerCase() !== 'submit') {

                var value = SSO.Util.getCredentialByFunction(credentialSet, currentField.type, newPassword);

                this.enterCred(doc, currentField, value);
            }
        }

        var submitField = currentForm.getCredential('submit');
        if (!SSO.Util.isNullOrEmpty(submitField)) {
            if (!SSO.Util.isNullOrEmpty(submitField.prejs)) {
                this.exec(submitField, submitField.prejs);
            }
            this.pressButton(doc,submitField.element, messageData);

            if (!SSO.Util.isNullOrEmpty(submitField.postjs)) {
                this.exec(submitField, submitField.postjs);
            }
        }
    },
    enterCred: function (doc, currentField, cred) {
        var control = currentField.element;
        if(!SSO.Util.isNullOrEmpty(cred))
            currentField.value = cred.value;
        if (!SSO.Util.isNullOrEmpty(currentField.prejs)) {
            this.exec(currentField,currentField.prejs);
        }

        if (!SSO.Util.isNullOrEmpty(control) && !SSO.Util.isNullOrEmpty(cred)) {
            if (!document.body.contains(control)) {
                var newControl;
                if (control.id)
                    newControl = document.getElementById(control.id);
                if (newControl == null && control.name) {
                    newControl = document.getElementsByName(control.name);

                    if (newControl.length > 0)
                        newControl = newControl[0];
                }

                if (newControl)
                    control = newControl;
            }

            SSO.Util.executeHTMLEvent(document, control, "focus");

            control.value = cred.value;

            SSO.Util.executeHTMLEvent(document, control, "input");
            SSO.Util.executeHTMLEvent(document, control, "change");

            SSO.Util.executeKeyEvent(document, control, "keydown", 40);
            SSO.Util.executeKeyEvent(document, control, "keypress", 40);
            SSO.Util.executeKeyEvent(document, control, "keyup", 40);

            SSO.Util.executeHTMLEvent(document, control, "blur");

            control.className += ' essom_changed';

            setTimeout(function () { control.className = control.className.replace(' essom_changed', ''); }, 700);
        }

        if (!SSO.Util.isNullOrEmpty(currentField.postjs)) {
            this.exec(currentField,currentField.postjs);
        }
    },
    exec: function (currentField,jsdata) {
        if (SSO.Util.isNullOrEmpty(jsdata) || SSO.Util.isNullOrEmpty(jsdata))
            return;
        var jsFunc = new Function('currentField',jsdata);
        
        jsFunc(currentField);
    },
    pressButton: function (doc, submitBtn, messageData)
    {
        if(submitBtn == null)
            return;
        
        submitBtn.disabled = false;

        if (messageData.pressButton !== true)
            return;

        if (this.changePwdDetected)
        {
            if (messageData.fromButton)
                submitBtn.click();
        }
        else
        {
            submitBtn.click();

           // var mouseEvt = doc.createEvent("MouseEvents");
            // mouseEvt.initMouseEvent("click", true, true, window, 1, 0, 0, 0, 0, true, true, true,true, 0, null),
            // doc.dispatchEvent(mouseEvt);

            //var eventObj = doc.createEventObject();
            //e.fireEvent("onclick", eventObj)
        }
    }
});



SSO.Manager = SSO.Class.extend({
    document: null,
    formDetected: false,
    bannerDisplayed: false,
    loginDetection: null,
    sendToBackground: null,
    inIframe: null,

    initialize: function (sendToBackgroundFunc, initListenerFunc, inIframeFunc) {

        var base = this;

        base.document = window.document;
        base.sendToBackground = sendToBackgroundFunc;
        base.inIframe = inIframeFunc;
        initListenerFunc(function (message) { base.receiveFromBackground(message); });

        if (document.getElementById("HelloID_url") !== null) {
            if (document.body !== undefined) {
                document.body.insertAdjacentHTML('afterbegin', '<div id="HelloID_extension_installed"></div>');
            }
            base.sendToBackground('Discovered', { 'portalUrl': document.getElementById("HelloID_url").innerText });
        }
        else {
            //send initialize action
            if (base.inIframe()) {
                var a = document.createElement('a');

                a.href = document.referrer;

                base.sendToBackground('Initialize', { hostname: a.hostname, href: document.referrer });
            }
            else {
                base.sendToBackground('Initialize', { hostname: window.location.hostname, href: window.location.href });
            }
        }
    },
    run: function (app, retryCount) {
        var base = this;

        if (base.loginDetection.detect()) {
            base.formDetected = true;
            base.loginDetection.createSubmitEvent(function () { base.submitHandler(base); });

            var messageData = {};
            messageData.applicationGUID = app.applicationGUID;
            messageData.changePwdDetected = base.loginDetection.changePwdDetected;

            this.sendToBackground('ShowCredBanner', messageData);
        }
        else {
            if (retryCount > 0) {
                retryCount--;
                setTimeout(function () { base.run(app, retryCount); }, 1000);
            }
            else {
                base.trackDOMChanges(app.applicationGUID);
            }
        }
    },
    receiveFromBackground: function (message) {
        switch (message.id) {

            case 'RetrievedApplicationData':

                if (this.loginDetection != null)
                    return true;

                if (message.data == null)
                    return true;

                var app = message.data;

                if (app.custom === '')
                    this.loginDetection = new SSO.Detection.LoginForm(this.document, app);
                else
                    this.loginDetection = new SSO.Detection.Custom(this.document, app);

                this.run(app, app.retryCount);

                return true;

            case 'SaveCredentialsQuestion':
                this.createSaveCredentialBanner(message.data);
                return true;

            case 'ShowCredBanner':
                this.createCredentialBanner(message.data);
                return true;
            case 'FillFormWithCredentials':
                if (this.formDetected)
                    this.loginDetection.fillFormWithCredentials(this.document, message.data);

                return true;
            case 'ChangePassword':
                if (this.formDetected)
                    this.loginDetection.changePassword(this.document, message.data);

                return true;
            case 'ShowSettingsBanner':
                this.createSettingsBanner(message.data);
                return true;
        }
        return true;
    },
    createCredentialBanner: function (messageData) {
        var base = this;
        if (base.bannerDisplayed === true)
            return;
        if (base.inIframe())
            return;
        base.bannerDisplayed = true;

        var banner = new SSO.Models.CredentialsBanner(base.document, messageData.app, messageData.changePwdDetected);

        banner.hook.register('CredentialSelected', function () { messageData.fromButton = true; base.sendToBackground('FillFormWithCredentials', messageData); return true; });
        banner.hook.register('ChangePassword', function () { messageData.fromButton = true; base.sendToBackground('ChangePassword', messageData); return true; });
        banner.hook.register('CloseBanner', function () { base.bannerDisplayed = false; });

        messageData.fromButton = false;
        this.sendToBackground('FillFormWithCredentials', messageData);
    },
    createSettingsBanner: function (app) {
        var base = this;
        if (base.bannerDisplayed === true)
            return;
        if (base.inIframe())
            return;
        base.bannerDisplayed = true;

        var banner = new SSO.Models.SettingsBanner(base.document, app);

        banner.hook.register('CloseBanner', function () { base.bannerDisplayed = false; });
    },

    createSaveCredentialBanner: function (app) {
        var base = this;

        if (base.bannerDisplayed === true)
            return;
        if (base.inIframe())
            return;
        base.bannerDisplayed = true;

        var banner = new SSO.Models.SaveCredentialsBanner(base.document, app.langSet);

        banner.hook.register('Cancel', function () { base.bannerDisplayed = false; base.sendToBackground('CancelSaveCredential', app.applicationGUID); });

        banner.hook.register('Save', function () { base.bannerDisplayed = false; base.sendToBackground('SaveCredential', app.applicationGUID); });
    },
    submitHandler: function (base) {
        base.sendToBackground('NewCredsPosted', base.loginDetection.getCredentials(event));
    },
    trackDOMChanges: function (applicationGUID) {
        var MutationObserver = window.MutationObserver || window.WebKitMutationObserver;
        var base = this;

        var observer = new MutationObserver(function (mutations, observer) {
            if (base.loginDetection.detect()) {
                observer.disconnect();
                base.formDetected = true;
                base.loginDetection.createSubmitEvent(base.submitHandler);

                var messageData = {};
                messageData.applicationGUID = applicationGUID;
                messageData.changePwdDetected = base.loginDetection.changePwdDetected;

                base.sendToBackground('ShowCredBanner', messageData);
                return;
            }
        });

        observer.observe(base.document, {
            childList: true,
            subtree: true
        });
    }

});


SSO.Detection.Custom = SSO.Detection.extend({
    loginScript: null,
    changePwdScript: null,

    initialize: function (doc,app) {
        this.doc = doc;
        this.app = app;

        if (!SSO.Util.isNullOrEmpty(app.custom) && app.custom !== '')
            this.loginScript = JSON.parse(SSO.Util.decodeBase64(app.custom));
        if (!SSO.Util.isNullOrEmpty(app.changePwdScript) && app.changePwdScript !== '')
            this.changePwdScript = JSON.parse(SSO.Util.decodeBase64(app.changePwdScript));
    },
    detect: function () {
        this.forms = [];

        if (this.performDetection(this.changePwdScript, true)) {
            this.changePwdDetected = true;
            return true;
        }
        if (this.performDetection(this.loginScript, false)) {
            this.loginDetected = true;
            return true;
        }

        return false;
    },
    performDetection: function (script,changepw) {
        if (SSO.Util.isNullOrEmpty(script))
            return false;

        var currentForm = new SSO.Form();

        currentForm.fields = script.fields;
        currentForm.changepw = changepw;

        var fields = currentForm.fields;
        var requiredSets = script.requiredSets;

        if (SSO.Util.isNullOrEmpty(fields))
            return false;

        for (var i = 0; i < fields.length; i++) {
            var field = fields[i];
            var fieldType = field.type;

            field.element = this.getElement(field);

            if (requiredSets == null && field.element == null)
                return false;

            if (field.element != null && currentForm.form == null) {
                currentForm.form = field.element.form;
            }
        }
        if (requiredSets == null) {
            if (changepw) {
                if (currentForm.getCredential('password') != null && currentForm.getCredential('newpassword') != null) {
                    this.forms.push(currentForm);
                    return true;
                }
            }
            else
            {
                if (currentForm.getCredential('username') != null && currentForm.getCredential('password') != null) {
                    this.forms.push(currentForm);
                    return true;
                }
            }
            return false;
        }

        for (var i = 0; i < requiredSets.length; i++) {
            var requiredSet = requiredSets[i];
            var setIncomplete = false;

            for (var j = 0; j < requiredSet.length; j++) {
                if (currentForm.hasElement(requiredSet[j].toLowerCase()) === false) {
                    setIncomplete = true;
                    break;
                }
            }

            if (!setIncomplete) {
                this.forms.push(currentForm);
                return true;
            }
        }

        return false;
    },
    getElement: function (field)
    {
        if (SSO.Util.isNullOrEmpty(field))
            return null;

        if (!SSO.Util.isNullOrEmpty(field.key))
            return this.getElementByNameOrID(field.key);
        if (!SSO.Util.isNullOrEmpty(field.classname))
            return this.getElementByClass(field.classname);
        if (!SSO.Util.isNullOrEmpty(field.query))
            return this.getElementByQuery(field.query);
        return null;
    },
    getElementByNameOrID: function (nameOrId)
    {
        var element = this.doc.getElementById(nameOrId);

        if (element)
            return element;

        var elements = this.doc.getElementsByName(nameOrId);

        if (elements == null)
            return null;
        if (elements.length !== 0)
            return elements[0];

        return null;
    },
    getElementByClass: function (className) {
        if (!this.doc['getElementsByClassName'])
            return null;

        var elements = this.doc.getElementsByClassName(className);

        if (elements == null)
            return null;
        if (elements.length !== 0)
            return elements[0];

        return null;
    },
    getElementByQuery: function (query) {
        if (this.doc['querySelector'])
            return this.doc.querySelector(query);

        return null;
    }
});

SSO.Detection.LoginForm = SSO.Detection.extend({

    usernameRgx: '(?:(?:login)|(?:logon.*id)|(?:id)|(?:token)|(?:usr)|(?:user)|(?:gebruiker)|(?:mail)|(?:name))',
    passwordRgx: '(?:(?:login)|(?:logon.*id)|(?:pass)|(?:wachtwoord)|(?:pwd)|(?:auth)|(?:key)|(?:secret)|(?:pin)|(?:token))',
    forgotpwdRgx: '(?:(?:pwd)|(?:forgot))',
    otherRequiredTypesRgx: '(?:(?:company)|(?:hint)|(?:captcha))',
    submitBtnRgx: '(?:(?:login)|(?:log.*in)|(?:logon)|(?:inloggen)|(?:aanmelden)|(?:log.on)|(?:submit)|(?:sign)|(ok)|(?:sign)|(enter))',
    signUpRgx : '(?:(:?signup)|(:?register)|(:?registreren))',

    detect: function () {
        var foundForms = this.doc.getElementsByTagName('form');
        var regFormDetected = false;
        this.forms = [];

        for (var i = 0; i < foundForms.length ; i++) {
            var currentForm = new SSO.Form();
            if (this.formHasCorrectFields(foundForms[i], currentForm)) {
                if (!this.doesFormLooksLikeSignUp(foundForms[i])) {
                    currentForm.form = foundForms[i];
                    this.forms.push(currentForm);
                }
                else {
                    regFormDetected = true;
                }
            }
        }
        if (this.forms.length !== 0) {
            this.loginDetected = true;
            return true;
        }

        if (regFormDetected === false)
        {
            if (document['querySelectorAll']) {
                if (this.detectFormless())
                {
                    this.loginDetected = true;
                    return true;
                }
            }
            else
            {
                if (this.detectFormlessOld())
                {
                    this.loginDetected = true;
                    return true;
                }
            }
        }

        return false;
    },
    detectFormlessOld: function ()
    {
        var currentForm = new SSO.Form();
        var i;
        var elm;

        var elements = this.doc.getElementsByTagName('input');
        
        for (i = 0; i < elements.length ; i++)
        {
            elm = elements[i];

            if (currentForm.getCredential('username') == null) {
                if (this.isUsername(elm))
                    currentForm.addField('username', elm);
            }
            else {
                if (currentForm.getCredential('password') == null) {
                    if (this.isPassword(elm))
                        currentForm.addField('password', elm);
                }
                else {
                    if (this.isSubmitButton(elm)) {
                        currentForm.addField('submit', elm);
                        this.forms.push(currentForm);
                        return true;
                    }
                }
            }
        }

        if (currentForm.getCredential('username') == null || currentForm.getCredential('password') == null)
            return false;

        if (currentForm.getCredential('submit') == null) {
            var buttonElements = this.doc.getElementsByTagName('button');

            for (i = 0; i < buttonElements.length ; i++) {
                elm = buttonElements[i];
                if (this.isSubmitButton(elm)) {
                    currentForm.addField('submit', elm);
                    this.forms.push(currentForm);
                    return true;
                }
            }
        }
        else
        {
            this.forms.push(currentForm);
            return true;
        }

        return false;
    },
    detectFormless: function ()
    {
        var currentForm = new SSO.Form();

        var elements = this.doc.querySelectorAll('input,button,a,span');
        
        for (var i = 0; i < elements.length ; i++)
        {
            var elm = elements[i];

            if (currentForm.getCredential('username') == null) {
                if (this.isUsername(elm))
                    currentForm.addField('username', elm);
            }
            else {
                if (currentForm.getCredential('password') == null) {
                    if (this.isPassword(elm))
                        currentForm.addField('password', elm);
                }
                else {
                    if (this.isSubmitButton(elm)) {
                        currentForm.addField('submit', elm);
                        this.forms.push(currentForm);
                        return true;
                    }
                }
            }
        }

        return false;
    },
    formHasCorrectFields: function (form, currentForm) {
        if (form == null)
            return false;

        if (this.findNodesInForm(form.childNodes, currentForm))
            return true;

        return false;
    },
    findNodesInForm: function (nodes, currentForm)
    {
        if (nodes == null)
            return false;

        for (var i = 0; i < nodes.length; i++) {
            var elm = nodes[i];

            if (currentForm.getCredential('username') == null) {
                if (this.isUsername(elm))
                    currentForm.addField('username', elm);
            }
            else {
                if (currentForm.getCredential('password') == null) {
                    if (this.isPassword(elm))
                        currentForm.addField('password', elm);
                }
                else {
                    if (this.isSubmitButton(elm)) {
                        currentForm.addField('submit', elm);
                        this.forms.push(currentForm);
                        return true;
                    }
                }
            }

            if (this.findNodesInForm(elm.childNodes, currentForm))
                return true;
        }

        return false;
    },
    doesFormLooksLikeSignUp : function(form) {

        if (this.isCorrectFormElement(new RegExp(this.signUpRgx, 'i'), form,false))
            return true;

        var elements = form.elements;

        var nrofPasswordFields = 0, nrofInputFields = 0;

        for (var i = 0; i < elements.length; i++)
        {
            var elm = elements[i];

            if (!this.isHidden(elm) && (elm.type === 'text' || elm.type === 'email') && !this.isOtherLoginElement(elm))
                nrofInputFields++;
            else if (this.isPassword(elm))
                nrofPasswordFields++;
        }

        //when it has more input field then required and multiple password fields it is most likely a signup form
        return (nrofPasswordFields === 2 && nrofInputFields >=5 );
    },
    isOtherLoginElement: function (elm)
    {
        if (elm == null)
            return false;

        var regex = new RegExp(this.otherRequiredTypesRgx, 'i');
        return this.isCorrectFormElement(regex, elm, false);
    },
    isUsername: function (elm) {
        if (elm == null)
            return false;

        if (elm.tagName !== 'INPUT')
            return false;

        if (elm.type !== 'text' && elm.type !== 'email' && elm.type !== 'password' && elm !== 'url')
            return false;

        var regex = new RegExp(this.usernameRgx, "i");
        return this.isCorrectFormElement(regex, elm, false);

    },
    isPassword: function (elm) {
        if (elm == null)
            return false;

        if (elm.tagName !== 'INPUT')
            return false;

        if (elm.type !== 'password')
            return false;

        var regex = new RegExp(this.passwordRgx, "i");
        return this.isCorrectFormElement(regex, elm, false);
    },
    isSubmitButton: function (elm) {
        if (elm == null)
            return false;
        
        var regex;

        if (elm.tagName === 'INPUT') {
            if (elm.type === 'submit')
                return true;
            if (elm.type === 'hidden' || elm.type === 'text' || elm.type === 'password' || elm.type === 'checkbox')
                return false;

            regex = new RegExp(this.submitBtnRgx, "i");

            return this.isCorrectFormElement(regex, elm,true);
        }

        if (elm.tagName === 'BUTTON' || elm.tagName === 'A' || elm.tagName === 'SPAN' || (elm.role && elm.role === 'button'))
        {
            if (this.isHidden(elm))
                return false;

            var text;

            if (SSO.Util.isNullOrEmpty(elm.textContent))
                text = elm.innerText;
            else
                text = elm.textContent;

            regex = new RegExp(this.forgotpwdRgx, "i");

            if (regex.exec(text))
                return false;

            regex = new RegExp(this.submitBtnRgx, "i");
            
            if (regex.exec(text))
                return this.isCorrectFormElement(regex, elm, true);
            
            return false
        }

        return false;
    },
    isCorrectFormElement: function (regex,elm,isButton)
    {
        if (this.isCorrectElement(regex, elm, isButton))
            return true;

        if (elm.parentNode)
            return this.isCorrectElement(regex, elm.parentNode, isButton);

        return false;
    },
    isCorrectElement: function (regex, elm, isButton)
    {
        if(elm == null)
            return false;

        if (elm.readOnly != null && elm.readOnly === true)
            return false;

        if (this.isHidden(elm))
            return false;

        if (elm.name)
            if (regex.exec(elm.name))
                return true;

        if (elm.id)
            if (regex.exec(elm.id))
                return true;

        if (elm.className)
            if (regex.exec(elm.className))
                return true;

        if (isButton === true)
        {
            if (elm.value)
                if (regex.exec(elm.value.replace(/ /g, '')))
                    return true;
        }

        var placeholder = elm.getAttribute('placeholder');
        if (placeholder !== null && regex.exec(placeholder))
            return true;

        var ariaLabel = elm.getAttribute('aria-label');
        if (ariaLabel !== null && regex.exec(ariaLabel))
            return true;

        return false;
    },
    isHidden: function(elm)
    {
        if (elm.offsetWidth === 0 ||
            elm.offsetHeight === 0 ||
            elm.style.visibility === 'hidden' ||
            elm.style.display === 'none' ||
            elm.style.opacity === 0
        ) return true;
        return false;
    }
});

SSO.Models.CredentialsBanner = SSO.Class.extend({
    document: null,
    app: null,
    bannerName: "cred",

    initialize: function (document, app, changePwdDetected) {

        var base = this;
        base.document = document;
        base.app = app;

        var body = document.body;

        if (body == null) {
            setTimeout(function () { base.initialize(document, app, changePwdDetected); }, 500);
            return;
        }

        body.insertAdjacentHTML('afterbegin', '<div id="helloid_credential_wrapper" class="essom_wrapper">');

        var div = document.createElement('div');
        div.id = 'helloid_credential_container';
        div.className = 'essom_container';

        var lang = SSO.Util.GetLanguage(app.langSet);

        var html = '<div id="helloid_credential_banner" class="essom_banner"><span class="left"><div class="essom_logo">';
        html += lang.EnterCred;
        html += ':</div></span><span class="left"><button type="button" id="helloid_entercred_btn" class="essom_btn essom_btn-success">';
        html += lang.Default;
        if (app.appOptions & 2) { //show creds
            html += '</button><button type="button" id="helloid_showcred_btn" class="essom_btn essom_btn-info">';
            html += lang.ShowCred;
        }
        if (app.appOptions & 4 && changePwdDetected) { //change pw
            html += '</button><button type="button" id="helloid_changepwd_btn" class="essom_btn essom_btn-info">';
            html += lang.ChangePwd;
        }
        html += '</button><button type="button" id="helloid_closebanner_btn" class="essom_btn essom_btn-close">';
        html += lang.Close;
        html += '</button>&nbsp;</span>';
        if (app.appOptions & 2) {
            html += '<div id="showCredForm" style="display: none"><label for="helloid_usr_view">username:&nbsp;</label><input type="text" id="helloid_usr_view"></input>&nbsp<label for="helloid_usr_view">Password:&nbsp;</label><input type="password" id="helloid_pwd_view"></input></div>';
        }
        html += '</div>';

        div.insertAdjacentHTML('afterBegin', html);
        body.insertAdjacentHTML('beforeEnd', '</div>');
        body.appendChild(div);

        var onEnterCred = SSO.Util.delegateEvent(base, 'onEnterCred', {});
        var onChangePwd = SSO.Util.delegateEvent(base, 'onChangePwd', {});
        var onClose = SSO.Util.delegateEvent(base, 'onClose', {});

        var enterCredBtn = document.getElementById("helloid_entercred_btn");
        var changePwdBtn = document.getElementById("helloid_changepwd_btn");
        var closeBtn = document.getElementById('helloid_closebanner_btn');
        var pwdEdit = document.getElementById('helloid_pwd_view');

        SSO.Util.addClickListener(enterCredBtn, onEnterCred);
        SSO.Util.addClickListener(changePwdBtn, onChangePwd);
        SSO.Util.addClickListener(closeBtn, onClose);

        SSO.Util.addMouseOverListener(pwdEdit, function () { var obj = document.getElementById('helloid_pwd_view'); if (obj !== null) obj.type = 'text'; });
        SSO.Util.addMouseOutListener(pwdEdit, function () { var obj = document.getElementById('helloid_pwd_view'); if (obj !== null) obj.type = 'password'; });

        if (app.appOptions & 2) {

            var onShowCred = SSO.Util.delegateEvent(base, 'onShowCred', {});
            var showCredBtn = document.getElementById("helloid_showcred_btn");
            SSO.Util.addClickListener(showCredBtn, onShowCred);
        }
    },
    deleteBanner: function () {
        var elm = this.document.getElementById('helloid_credential_banner');

        if (elm)
            elm.parentNode.removeChild(elm);

        elm = this.document.getElementById('helloid_credential_wrapper');

        if (elm)
            elm.parentNode.removeChild(elm);
    },
    onEnterCred: function (event, args) {
        this.hook.call('CredentialSelected');
    },
    onChangePwd: function (){
        this.hook.call('ChangePassword');
    },
    onShowCred: function (event, args) {
        var showCredForm = this.document.getElementById('showCredForm');
        var lang = SSO.Util.GetLanguage(this.app.langSet);

        if (showCredForm.style.display === 'none')
        {
            showCredForm.style.display = 'inline';

            var credentialSet = this.app.credentialSets[0];

            var username = SSO.Util.getCredentialByFunction(credentialSet, "username");
            var password = SSO.Util.getCredentialByFunction(credentialSet, "password");

            var helloid_usr_view = this.document.getElementById('helloid_usr_view');
            helloid_usr_view.value = username.value;
            var helloid_pwd_view = this.document.getElementById('helloid_pwd_view');
            helloid_pwd_view.value = password.value;

            var showCredBtn = document.getElementById("helloid_showcred_btn");

            showCredBtn.innerHTML= lang.HideCred;
        }
        else {
            showCredForm.style.display = 'none';

            var showCredBtn = document.getElementById("helloid_showcred_btn");

            showCredBtn.innerHTML= lang.ShowCred;
        }

        

    },
    onClose: function (event, args) {
        this.deleteBanner();
        this.hook.call('CloseBanner');
    }
});

SSO.Models.Message = SSO.Class.extend({

    id: null,
    data: {},

    initialize: function (id, data) {
        this.id = id;
        this.data = data;
    }
});

SSO.Models.SaveCredentialsBanner = SSO.Class.extend({
    document: null,
    bannerName: "save",

    initialize: function (document, langSet) {
        var self = this; //functional reference
        this.document = document;
        this.createUI(langSet);
        this.addEvents();
    },

    createUI: function (langSet) {
        //create banner
        var base = this;
        var body = base.document.body;

        if (body == null)
        {
            setTimeout(function () { base.createUI(langSet); }, 500);
            return;
        }

        body.insertAdjacentHTML('afterbegin', '<div id="essom_save_credential_wrapper" class="essom_wrapper">');

        var div = base.document.createElement('div');
        div.id = 'essom_save_container';
        div.className = 'essom_container';

        var lang = SSO.Util.GetLanguage(langSet);
       
        var html = '<div id="essom_save_banner" class="essom_banner"><span class="left"><div class="essom_logo">';
        html += lang.SaveQuestion;
        html += '</div></span><span class="left" id="essom_credentials"><button type="button" id="essom_save_credentials_btn" class="essom_btn essom_btn-success">';
        html += lang.Save;
        html += '</button><button type="button" id="essom_incorrect_credentials_btn" class="essom_btn essom_btn-info">';
        html += lang.Incorrect;
        html += '</button><button type="button" id="essom_notnow_credentials_btn" class="essom_btn">';
        html += lang.NotNow;
        html += '</button><button type="button" id="essom_close_credentials_btn" class="essom_btn essom_btn-close">';
        html += lang.Close;
        html += '</button>&nbsp;</span></div>';

        div.insertAdjacentHTML('afterBegin', html);
        body.insertAdjacentHTML('beforeEnd', '</div>');
        body.appendChild(div);
    },


    addEvents: function () {

        var save = SSO.Util.delegateEvent(this, 'onSave', {});
        var cancel = SSO.Util.delegateEvent(this, 'onCancel', {});

        //need to change addevent to an attach event from the utils
        var saveBtn = this.document.getElementById('essom_save_credentials_btn');
        var notnowBtn = this.document.getElementById('essom_notnow_credentials_btn');
        var incorrectBtn = this.document.getElementById('essom_incorrect_credentials_btn');
        var closeBtn = this.document.getElementById('essom_close_credentials_btn');

        SSO.Util.addClickListener(saveBtn, save);
        SSO.Util.addClickListener(notnowBtn, cancel);
        SSO.Util.addClickListener(incorrectBtn, cancel);
        SSO.Util.addClickListener(closeBtn, cancel);
 
    },

    deleteBanner: function()
    {
        var elmWrp = this.document.getElementById('essom_save_credential_wrapper');

        if (elmWrp && elmWrp.parentNode != undefined)
            elmWrp.parentNode.removeChild(elmWrp);

        var elmCnt = this.document.getElementById('essom_save_container');

        if (elmCnt && elmCnt.parentNode != undefined)
            elmCnt.parentNode.removeChild(elmCnt);
    },

    onSave: function (event, args) {
        this.deleteBanner();
        this.hook.call('Save');
    },
     
    onCancel: function (event, args) {
        this.deleteBanner();
        this.hook.call('Cancel');
    }
});

try
{
    module.exports = SSO;
}
catch(e)
{

}
SSO.Models.SettingsBanner = SSO.Class.extend({
    document: null,
    app: null,
    bannerName: "settings",

    initialize: function (document, app) {

        var base = this;
        base.document = document;
        base.app = app;

        var body = document.body;

        if (body == null) {
            setTimeout(function () { base.initialize(document,app); }, 500);
            return;
        }

        body.insertAdjacentHTML('afterbegin', '<div id="helloid_settings_wrapper" class="essom_wrapper essomhide">');

        var div = document.createElement('div');
        div.id = 'helloid_settings_container';
        div.className = 'essom_container essomhide';

        var lang = SSO.Util.GetLanguage(app.langSet);

        var html = '<div id="helloid_settings_banner" class="essom_banner""><span class="left"><div class="essom_logo"></div></span><span class="left"><button type="button" id="helloid_showcred_btn" class="essom_btn essom_btn-info essomhide">';
        html += lang.ShowCred;
        html += '</button><button type="button" id="helloid_hidebanner_btn" class="essom_btn essom_btn-close essomhide">';
        html += lang.Close;
        html += '</button>&nbsp;</span><div id="showCredForm" style="display: none"><label for="helloid_usr_view">username:&nbsp;</label><input type="text" id="helloid_usr_view"></input>&nbsp<label for="helloid_usr_view">Password:&nbsp;</label><input type="password" id="helloid_pwd_view" onmouseover="var obj = document.getElementById(\'helloid_pwd_view\'); obj.type = \'text\';" onmouseout="var obj = document.getElementById(\'helloid_pwd_view\'); obj.type = \'password\';"></input></div></div>';

        div.insertAdjacentHTML('afterBegin', html);
        body.insertAdjacentHTML('beforeEnd', '</div>');
        body.appendChild(div);

        var onShowBanner = SSO.Util.delegateEvent(base, 'onShowBanner', {});
        var onShowCred = SSO.Util.delegateEvent(base, 'onShowCred', {});
        var onHide = SSO.Util.delegateEvent(base, 'onHide', {});

        var settingsBanner = document.getElementById("helloid_settings_banner");
        var showCredBtn = document.getElementById("helloid_showcred_btn");
        var hideBtn = base.document.getElementById('helloid_hidebanner_btn');

        SSO.Util.addClickListener(settingsBanner, onShowBanner);
        SSO.Util.addClickListener(showCredBtn, onShowCred);
        SSO.Util.addClickListener(hideBtn, onHide);
    },
    deleteBanner: function () {
        var elm = this.document.getElementById('helloid_settings_banner');

        if (elm)
            elm.parentNode.removeChild(elm);

        elm = this.document.getElementById('helloid_settings_wrapper');

        if (elm)
            elm.parentNode.removeChild(elm);
    },
    onShowBanner: function () {
        
        var elm = document.getElementById("helloid_settings_wrapper");
        elm.className = "essom_wrapper";
        elm = document.getElementById("helloid_settings_container");
        elm.className = "essom_container";
        elm = document.getElementById("helloid_settings_banner");
        elm.className = "essom_banner";
        elm = document.getElementById("helloid_showcred_btn");
        elm.className = "essom_btn essom_btn-info";
        elm = document.getElementById("helloid_hidebanner_btn");
        elm.className = "essom_btn essom_btn-close";

    },
    onShowCred: function (event, args) {
        var showCredForm = this.document.getElementById('showCredForm');
        var lang = SSO.Util.GetLanguage(this.app.langSet);
        var showCredBtn = document.getElementById("helloid_showcred_btn");

        if (showCredForm.style.display === 'none') {
            showCredForm.style.display = 'inline';

            var credentialSet = this.app.credentialSets[0];

            var username = SSO.Util.getCredentialByFunction(credentialSet, "username");
            var password = SSO.Util.getCredentialByFunction(credentialSet, "password");

            var helloid_usr_view = this.document.getElementById('helloid_usr_view');
            helloid_usr_view.value = username.value;
            var helloid_pwd_view = this.document.getElementById('helloid_pwd_view');
            helloid_pwd_view.value = password.value;


            showCredBtn.innerHTML = lang.HideCred;
        }
        else {
            showCredForm.style.display = 'none';

            showCredBtn.innerHTML = lang.ShowCred;
        }

    },
    onHide: function (event, args) {
        this.deleteBanner();
        this.hook.call('CloseSettings');
    }
});
